@@ -3,9 +3,6 @@
 
 ######################### We start with some black magic to print on failure.
 
-# Change 1..1 below to 1..last_test_to_print .
-# (It may become useful if the test is moved to ./t subdirectory.)
-
 END {print "not ok 1\n" unless $loaded;}
 use HTML::CalendarMonthSimple;
 $loaded = 1;
@@ -13,7 +10,7 @@ print "ok 1\n";
 
 ######################### End of black magic.
 
-# Insert your test code below (better if it prints "ok 13"
-# (correspondingly "not ok 13") depending on the success of chunk 13
-# of the test code):
+# test instantiation of a new calendar object
+my $cal = new HTML::CalendarMonthSimple();
+if ($cal) { print "ok 2\n"; } else { die "not ok 2\n"; }
 
